@@ -23,7 +23,7 @@ use Crypt::AuthEnc::GCM;
 use Crypt::Cipher::AES;
 use Crypt::Cipher::Camellia;
 use Crypt::Cipher::RC6;
-use Crypt::HC128;
+#use Crypt::HC128;
 use Crypt::KeyDerivation qw(hkdf);
 use Crypt::Mode::CFB;
 use Crypt::Mode::CTR;
@@ -41,7 +41,7 @@ use Digest::MD5;
 #use Mcrypt qw(:FUNCS);
 #use String::HexConvert ':all';
 
-our $VERSION = '0.9.3.1';
+our $VERSION = '0.9.3.2';
 
 our %_ciphers = 
     (
@@ -355,7 +355,7 @@ Net::Shadowsocks - the asynchronous, non-blocking shadowsocks client and server.
 
 =head1 VERSION
 
-Version 0.9.3.1
+Version 0.9.3.2
 
 =head1 SYNOPSIS
     
